@@ -15,7 +15,7 @@
 import json
 import os
 import sys
-
+import logging
 from yaml import Dumper, dump
 
 from data_validation import (
@@ -31,6 +31,15 @@ from data_validation.data_validation import DataValidation
 # by default yaml dumps lists as pointers. This disables that feature
 Dumper.ignore_aliases = lambda *args: True
 
+# Log level mappings for the input argument of log level string
+LOG_LEVEL_MAP = {
+    "DEBUG": logging.DEBUG,
+    "INFO": logging.INFO,
+    "WARNING": logging.WARNING,
+    "ERROR": logging.ERROR,
+    "CRITICAL": logging.CRITICAL,
+}
+
 
 def _get_arg_config_file(args):
     """Return String yaml config file path."""
@@ -62,6 +71,14 @@ def get_aggregate_config(args, config_manager):
         "int64",
         "decimal",
         "timestamp",
+        "float64[non-nullable]",
+        "float32[non-nullable]",
+        "int8[non-nullable]",
+        "int16[non-nullable]",
+        "int32[non-nullable]",
+        "int64[non-nullable]",
+        "decimal[non-nullable]",
+        "timestamp[non-nullable]",
     ]
 
     if args.wildcard_include_string_len:
@@ -114,12 +131,22 @@ def get_calculated_config(args, config_manager):
         col_list = None if args.hash == "*" else cli_tools.get_arg_list(args.hash)
         fields = config_manager._build_dependent_aliases("hash", col_list)
         aliases = [field["name"] for field in fields]
-
+        # config_manager.append_dependent_aliases(aliases)
         # Add to list of necessary columns for selective hashing in order to drop
         # excess columns with invalid data types (i.e structs) when generating source/target DFs
         if col_list:
             config_manager.append_dependent_aliases(col_list)
             config_manager.append_dependent_aliases(aliases)
+    elif args.concat:
+        col_list = None if args.concat == "*" else cli_tools.get_arg_list(args.concat)
+        fields = config_manager._build_dependent_aliases("concat", col_list)
+        aliases = [field["name"] for field in fields]
+        # config_manager.append_dependent_aliases(aliases)
+        # Add to list of necessary columns for selective concatenation in order to drop
+        # excess columns with invalid data types (i.e structs) when generating source/target DFs
+        if col_list:
+            config_manager.append_dependent_aliases(col_list)
+            config_manager.append_dependent_aliases(aliases)
 
     if len(fields) > 0:
         max_depth = max([x["depth"] for x in fields])
@@ -141,6 +168,12 @@ def get_calculated_config(args, config_manager):
                 ["hash__all"], depth=max_depth
             )
         )
+    elif args.concat:
+        config_manager.append_comparison_fields(
+            config_manager.build_config_comparison_fields(
+                ["concat__all"], depth=max_depth
+            )
+        )
     return calculated_configs
 
 
@@ -160,6 +193,7 @@ def build_config_from_args(args, config_manager):
                 config_manager.build_column_configs(grouped_columns)
             )
     elif config_manager.validation_type == consts.ROW_VALIDATION:
+        calc_type = args.hash or args.concat
         if args.comparison_fields is not None:
             comparison_fields = cli_tools.get_arg_list(
                 args.comparison_fields, default_value=[]
@@ -167,7 +201,7 @@ def build_config_from_args(args, config_manager):
             config_manager.append_comparison_fields(
                 config_manager.build_config_comparison_fields(comparison_fields)
             )
-            if args.hash != "*":
+            if calc_type is not None and calc_type != "*":
                 config_manager.append_dependent_aliases(comparison_fields)
 
     if args.primary_keys is not None:
@@ -175,7 +209,7 @@ def build_config_from_args(args, config_manager):
         config_manager.append_primary_keys(
             config_manager.build_column_configs(primary_keys)
         )
-        if args.hash != "*":
+        if calc_type is not None and calc_type != "*":
             config_manager.append_dependent_aliases(primary_keys)
 
     if config_manager.validation_type == consts.CUSTOM_QUERY:
@@ -200,20 +234,17 @@ def build_config_managers_from_args(args):
     """Return a list of config managers ready to execute."""
     configs = []
 
-    if args.type is None:
-        validate_cmd = args.validate_cmd.capitalize()
-        if validate_cmd == "Schema":
-            config_type = consts.SCHEMA_VALIDATION
-        elif validate_cmd == "Column":
-            config_type = consts.COLUMN_VALIDATION
-        elif validate_cmd == "Row":
-            config_type = consts.ROW_VALIDATION
-        elif validate_cmd == "Custom-query":
-            config_type = consts.CUSTOM_QUERY
-        else:
-            raise ValueError(f"Unknown Validation Type: {validate_cmd}")
+    validate_cmd = args.validate_cmd.capitalize()
+    if validate_cmd == "Schema":
+        config_type = consts.SCHEMA_VALIDATION
+    elif validate_cmd == "Column":
+        config_type = consts.COLUMN_VALIDATION
+    elif validate_cmd == "Row":
+        config_type = consts.ROW_VALIDATION
+    elif validate_cmd == "Custom-query":
+        config_type = consts.CUSTOM_QUERY
     else:
-        config_type = args.type
+        raise ValueError(f"Unknown Validation Type: {validate_cmd}")
 
     result_handler_config = None
     if args.bq_result_handler:
@@ -249,9 +280,17 @@ def build_config_managers_from_args(args):
 
     is_filesystem = source_client._source_type == "FileSystem"
     tables_list = cli_tools.get_tables_list(
-        args.tables_list, default_value=[], is_filesystem=is_filesystem
+        args.tables_list, default_value=[{}], is_filesystem=is_filesystem
     )
 
+    filter_status = None
+    if args.filter_status is not None:
+        arg_list = cli_tools.get_arg_list(args.filter_status)
+        if all(arg in consts.VALIDATION_STATUSES for arg in arg_list):
+            filter_status = arg_list
+        else:
+            raise ValueError("An unsupported status was provided")
+
     for table_obj in tables_list:
         config_manager = ConfigManager.build_config_manager(
             config_type,
@@ -267,10 +306,17 @@ def build_config_managers_from_args(args):
             target_client=target_client,
             result_handler_config=result_handler_config,
             filter_config=filter_config,
+            filter_status=filter_status,
             verbose=args.verbose,
         )
         if config_type != consts.SCHEMA_VALIDATION:
             config_manager = build_config_from_args(args, config_manager)
+        else:
+            if args.exclusion_columns is not None:
+                exclusion_columns = cli_tools.get_arg_list(args.exclusion_columns)
+                config_manager.append_exclusion_columns(
+                    [col.casefold() for col in exclusion_columns]
+                )
 
         configs.append(config_manager)
 
@@ -488,12 +534,16 @@ def validate(args):
 
 
 def main():
+
     # Create Parser and Get Deployment Info
     args = cli_tools.get_parsed_args()
+    logging.basicConfig(
+        level=LOG_LEVEL_MAP[args.log_level],
+        format="%(asctime)s-%(levelname)s: %(message)s",
+        datefmt="%m/%d/%Y %I:%M:%S %p",
+    )
 
-    if args.command == "run":
-        run(args)
-    elif args.command == "connections":
+    if args.command == "connections":
         run_connections(args)
     elif args.command == "run-config":
         run_config(args)
