@@ -47,6 +47,7 @@ import csv
 import json
 import sys
 import uuid
+import logging
 
 from data_validation import consts
 from data_validation import state_manager
@@ -150,6 +151,13 @@ def configure_arg_parser():
     )
 
     parser.add_argument("--verbose", "-v", action="store_true", help="Verbose logging")
+    parser.add_argument(
+        "--log-level",
+        "-ll",
+        default="INFO",
+        choices=["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"],
+        help="Log Level to be assigned. This will print logs with level same or above",
+    )
 
     subparsers = parser.add_subparsers(dest="command")
     _configure_validate_parser(subparsers)
@@ -158,7 +166,6 @@ def configure_arg_parser():
     _configure_connection_parser(subparsers)
     _configure_find_tables(subparsers)
     _configure_raw_query(subparsers)
-    _configure_run_parser(subparsers)
     _configure_beta_parser(subparsers)
     return parser
 
@@ -170,7 +177,6 @@ def _configure_beta_parser(subparsers):
     )
     beta_subparsers = connection_parser.add_subparsers(dest="beta_cmd")
 
-    _configure_run_parser(beta_subparsers)
     _configure_validate_parser(beta_subparsers)
     _configure_deploy(beta_subparsers)
 
@@ -255,96 +261,6 @@ def _configure_validation_config_parser(subparsers):
     )
 
 
-def _configure_run_parser(subparsers):
-    """Configure arguments to run a data validation."""
-
-    # subparsers = parser.add_subparsers(dest="command")
-
-    run_parser = subparsers.add_parser(
-        "run", help="Run a validation and optionally store to config (deprecated)"
-    )
-
-    run_parser.add_argument(
-        "--type",
-        "-t",
-        help="Type of Data Validation (Column, GroupedColumn, Row, Schema)",
-    )
-    run_parser.add_argument("--source-conn", "-sc", help="Source connection name")
-    run_parser.add_argument("--target-conn", "-tc", help="Target connection name")
-    run_parser.add_argument(
-        "--tables-list",
-        "-tbls",
-        help="Comma separated tables list in the form 'schema.table=target_schema.target_table'",
-    )
-    run_parser.add_argument(
-        "--result-handler-config", "-rc", help="Result handler config details"
-    )
-    run_parser.add_argument(
-        "--bq-result-handler", "-bqrh", help="BigQuery result handler config details"
-    )
-    run_parser.add_argument(
-        "--config-file",
-        "-c",
-        help="Store the validation in the YAML Config File Path specified",
-    )
-    run_parser.add_argument(
-        "--labels",
-        "-l",
-        help="Key value pair labels for validation run",
-    )
-    run_parser.add_argument(
-        "--hash",
-        "-hash",
-        help="Comma separated list of columns for hash 'col_a,col_b' or * for all columns",
-    )
-    run_parser.add_argument(
-        "--service-account",
-        "-sa",
-        help="Path to SA key file for result handler output",
-    )
-    run_parser.add_argument(
-        "--threshold",
-        "-th",
-        type=threshold_float,
-        help="Float max threshold for percent difference",
-    )
-    run_parser.add_argument(
-        "--filters",
-        "-filters",
-        help="Filters in the format source_filter:target_filter",
-    )
-    run_parser.add_argument(
-        "--format",
-        "-fmt",
-        default="table",
-        help="Set the format for printing command output, Supported formats are (text, csv, json, table). It defaults "
-        "to table",
-    )
-    run_parser.add_argument(
-        "--use-random-row",
-        "-rr",
-        action="store_true",
-        help="Finds a set of random rows of the first primary key supplied.",
-    )
-    run_parser.add_argument(
-        "--random-row-batch-size",
-        "-rbs",
-        help="Row batch size used for random row filters (default 10,000).",
-    )
-    run_parser.add_argument(
-        "--wildcard-include-string-len",
-        "-wis",
-        action="store_true",
-        help="Include string fields for wildcard aggregations.",
-    )
-    run_parser.add_argument(
-        "--cast-to-bigint",
-        "-ctb",
-        action="store_true",
-        help="Cast any int32 fields to int64 for large aggregations.",
-    )
-
-
 def _configure_connection_parser(subparsers):
     """Configure the Parser for Connection Management."""
     connection_parser = subparsers.add_parser(
@@ -421,6 +337,11 @@ def _configure_row_parser(row_parser):
         "-hash",
         help="Comma separated list of columns for hash 'col_a,col_b' or * for all columns",
     )
+    row_parser.add_argument(
+        "--concat",
+        "-concat",
+        help="Comma separated list of columns for concat 'col_a,col_b' or * for all columns",
+    )
     row_parser.add_argument(
         "--comparison-fields",
         "-comp-fields",
@@ -494,6 +415,11 @@ def _configure_column_parser(column_parser):
         "-hash",
         help="Comma separated list of columns for hashing a concatenate 'col_a,col_b' or * for all columns",
     )
+    column_parser.add_argument(
+        "--concat",
+        "-concat",
+        help="Comma separated list of columns for a concatenate operation 'col_a,col_b' or * for all columns",
+    )
     column_parser.add_argument(
         "--bit_xor",
         "-bit_xor",
@@ -551,8 +477,13 @@ def _configure_column_parser(column_parser):
 
 
 def _configure_schema_parser(schema_parser):
-    """Configure arguments to run column level validations."""
+    """Configure arguments to run schema level validations."""
     _add_common_arguments(schema_parser)
+    schema_parser.add_argument(
+        "--exclusion-columns",
+        "-ec",
+        help="Comma separated list of columns 'col_a,col_b' to be excluded from the schema validation",
+    )
 
 
 def _configure_custom_query_parser(custom_query_parser):
@@ -685,6 +616,12 @@ def _add_common_arguments(parser):
         help="Set the format for printing command output, Supported formats are (text, csv, json, table). Defaults "
         "to table",
     )
+    parser.add_argument(
+        "--filter-status",
+        "-fs",
+        # TODO: update if we start to support other statuses
+        help="Comma separated list of statuses to filter the validation results. Supported statuses are (success, fail). If no list is provided, all statuses are returned",
+    )
 
 
 def get_connection_config_from_args(args):
@@ -771,7 +708,7 @@ def list_connections():
     connections = mgr.list_connections()
 
     for conn_name in connections:
-        print(f"Connection Name: {conn_name}")
+        logging.info(f"Connection Name: {conn_name}")
 
 
 def get_connection(connection_name):
@@ -802,9 +739,9 @@ def list_validations():
     mgr = state_manager.StateManager()
     validations = mgr.list_validations()
 
-    print("Validation YAMLs found:")
+    logging.info("Validation YAMLs found:")
     for validation_name in validations:
-        print(f"{validation_name}.yaml")
+        logging.info(f"{validation_name}.yaml")
 
 
 def get_labels(arg_labels):
