@@ -15,7 +15,7 @@
 
 import copy
 import warnings
-
+import logging
 import google.oauth2.service_account
 import ibis
 import ibis.backends.pandas
@@ -204,7 +204,7 @@ def get_all_tables(client, allowed_schemas=None):
         try:
             tables = list_tables(client, schema_name)
         except Exception as e:
-            print(f"List Tables Error: {schema_name} -> {e}")
+            logging.warning(f"List Tables Error: {schema_name} -> {e}")
             continue
 
         for table_name in tables:
