@@ -21,7 +21,7 @@ original data type is used.
 import datetime
 import functools
 import json
-
+import logging
 import ibis
 import ibis.expr.datatypes
 
@@ -71,15 +71,12 @@ def generate_report(
             "Expected source and target to have same schema, got "
             f"source: {source_names} target: {target_names}"
         )
-
     differences_pivot = _calculate_differences(
         source, target, join_on_fields, run_metadata.validations, is_value_comparison
     )
-
     source_pivot = _pivot_result(
         source, join_on_fields, run_metadata.validations, consts.RESULT_TYPE_SOURCE
     )
-
     target_pivot = _pivot_result(
         target, join_on_fields, run_metadata.validations, consts.RESULT_TYPE_TARGET
     )
@@ -87,8 +84,8 @@ def generate_report(
     documented = _add_metadata(joined, run_metadata)
 
     if verbose:
-        print("-- ** Combiner Query ** --")
-        print(documented.compile())
+        logging.debug("-- ** Combiner Query ** --")
+        logging.debug(documented.compile())
 
     result_df = client.execute(documented)
     result_df.validation_status.fillna(consts.VALIDATION_STATUS_FAIL, inplace=True)
@@ -105,6 +102,17 @@ def _calculate_difference(field_differences, datatype, validation, is_value_comp
         # Float64 type results from AVG() aggregation
         source_value = field_differences["differences_source_value"].round(digits=4)
         target_value = field_differences["differences_target_value"].round(digits=4)
+    elif isinstance(datatype, ibis.expr.datatypes.Decimal):
+        source_value = (
+            field_differences["differences_source_value"]
+            .cast("float64")
+            .round(digits=4)
+        )
+        target_value = (
+            field_differences["differences_target_value"]
+            .cast("float64")
+            .round(digits=4)
+        )
     else:
         source_value = field_differences["differences_source_value"]
         target_value = field_differences["differences_target_value"]
@@ -231,7 +239,6 @@ def _pivot_result(result, join_on_fields, validations, result_type):
         else all_fields
     )
     pivots = []
-
     for field in validation_fields:
         if field not in validations:
             continue
@@ -273,7 +280,6 @@ def _pivot_result(result, join_on_fields, validations, result_type):
                     + join_on_fields
                 )
             )
-
     pivot = functools.reduce(lambda pivot1, pivot2: pivot1.union(pivot2), pivots)
     return pivot
 
