@@ -281,6 +281,22 @@ class ConfigManager(object):
         """Return threshold from Config"""
         return self._config.get(consts.CONFIG_THRESHOLD, 0.0)
 
+    @property
+    def exclusion_columns(self):
+        """Return the exclusion columns from Config"""
+        return self._config.get(consts.CONFIG_EXCLUSION_COLUMNS, [])
+
+    @property
+    def filter_status(self):
+        """Return filter status list from Config"""
+        return self._config.get(consts.CONFIG_FILTER_STATUS, None)
+
+    def append_exclusion_columns(self, column_configs):
+        """Append exclusion columns to existing config."""
+        self._config[consts.CONFIG_EXCLUSION_COLUMNS] = (
+            self.exclusion_columns + column_configs
+        )
+
     def get_source_ibis_table(self):
         """Return IbisTable from source."""
         if not hasattr(self, "_source_ibis_table"):
@@ -340,8 +356,11 @@ class ConfigManager(object):
                 cols_filter_list = consts.SCHEMA_VALIDATION_COLUMN_FILTER_LIST
             else:
                 cols_filter_list = consts.COLUMN_FILTER_LIST
+            # handler that display results either to output or in a file
             return TextResultHandler(
-                self._config.get(consts.CONFIG_FORMAT, "table"), cols_filter_list
+                self._config.get(consts.CONFIG_FORMAT, "table"),
+                self.filter_status,
+                cols_filter_list,
             )
 
         result_type = self.result_handler_config[consts.CONFIG_TYPE]
@@ -360,7 +379,10 @@ class ConfigManager(object):
             else:
                 credentials = None
             return BigQueryResultHandler.get_handler_for_project(
-                project_id, table_id=table_id, credentials=credentials
+                project_id,
+                self.filter_status,
+                table_id=table_id,
+                credentials=credentials,
             )
         else:
             raise ValueError(f"Unknown ResultHandler Class: {result_type}")
@@ -380,6 +402,7 @@ class ConfigManager(object):
         target_client=None,
         result_handler_config=None,
         filter_config=None,
+        filter_status=None,
         verbose=False,
     ):
         if isinstance(filter_config, dict):
@@ -390,13 +413,15 @@ class ConfigManager(object):
             consts.CONFIG_TYPE: config_type,
             consts.CONFIG_SOURCE_CONN_NAME: source_conn_name,
             consts.CONFIG_TARGET_CONN_NAME: target_conn_name,
-            consts.CONFIG_TABLE_NAME: table_obj[consts.CONFIG_TABLE_NAME],
-            consts.CONFIG_SCHEMA_NAME: table_obj[consts.CONFIG_SCHEMA_NAME],
+            consts.CONFIG_TABLE_NAME: table_obj.get(consts.CONFIG_TABLE_NAME, None),
+            consts.CONFIG_SCHEMA_NAME: table_obj.get(consts.CONFIG_SCHEMA_NAME, None),
             consts.CONFIG_TARGET_SCHEMA_NAME: table_obj.get(
-                consts.CONFIG_TARGET_SCHEMA_NAME, table_obj[consts.CONFIG_SCHEMA_NAME]
+                consts.CONFIG_TARGET_SCHEMA_NAME,
+                table_obj.get(consts.CONFIG_SCHEMA_NAME, None),
             ),
             consts.CONFIG_TARGET_TABLE_NAME: table_obj.get(
-                consts.CONFIG_TARGET_TABLE_NAME, table_obj[consts.CONFIG_TABLE_NAME]
+                consts.CONFIG_TARGET_TABLE_NAME,
+                table_obj.get(consts.CONFIG_TABLE_NAME, None),
             ),
             consts.CONFIG_LABELS: labels,
             consts.CONFIG_THRESHOLD: threshold,
@@ -405,6 +430,7 @@ class ConfigManager(object):
             consts.CONFIG_FILTERS: filter_config,
             consts.CONFIG_USE_RANDOM_ROWS: use_random_rows,
             consts.CONFIG_RANDOM_ROW_BATCH_SIZE: random_row_batch_size,
+            consts.CONFIG_FILTER_STATUS: filter_status,
         }
 
         return ConfigManager(
@@ -552,13 +578,13 @@ class ConfigManager(object):
             if column not in allowlist_columns:
                 continue
             elif column not in casefold_target_columns:
-                print(
+                logging.warning(
                     f"Skipping {agg_type} on {column} as column is not present in target table"
                 )
                 continue
             elif supported_types and column_type not in supported_types:
                 if self.verbose:
-                    print(
+                    logging.info(
                         f"Skipping {agg_type} on {column} due to data type: {column_type}"
                     )
                 continue
@@ -616,7 +642,7 @@ class ConfigManager(object):
             elif supported_types and column_type not in supported_types:
                 if self.verbose:
                     msg = f"Skipping {calc_type} on {column} due to data type: {column_type}"
-                    print(msg)
+                    logging.info(msg)
                 continue
 
         calculated_config = {
@@ -647,6 +673,14 @@ class ConfigManager(object):
                 "concat",
                 "hash",
             ]
+        if calc_type == "concat":
+            order_of_operations = [
+                "cast",
+                "ifnull",
+                "rstrip",
+                "upper",
+                "concat",
+            ]
         column_aliases = {}
         col_names = []
         for i, calc in enumerate(order_of_operations):
