@@ -56,6 +56,8 @@ CONFIG_FILTER_SOURCE_COLUMN = "source_column"
 CONFIG_FILTER_SOURCE_VALUE = "source_value"
 CONFIG_FILTER_TARGET_COLUMN = "target_column"
 CONFIG_FILTER_TARGET_VALUE = "target_value"
+CONFIG_EXCLUSION_COLUMNS = "exclusion_columns"
+CONFIG_FILTER_STATUS = "filter_status"
 
 CONFIG_RESULT_HANDLER = "result_handler"
 
@@ -116,6 +118,11 @@ TARGET_AGG_VALUE = "target_agg_value"
 VALIDATION_STATUS = "validation_status"
 VALIDATION_STATUS_SUCCESS = "success"
 VALIDATION_STATUS_FAIL = "fail"
+# TODO: update if we start to support other statuses
+VALIDATION_STATUSES = [
+    VALIDATION_STATUS_SUCCESS,
+    VALIDATION_STATUS_FAIL,
+]
 
 # SQL Template Formatting
 # TODO: should this be managed in query_builder if that is the only place its used?
@@ -147,6 +154,9 @@ SCHEMA_VALIDATION_COLUMN_FILTER_LIST = [
     "start_time",
     "end_time",
     "aggregation_type",
-    "source_agg_value",
-    "target_agg_value",
+    "difference",
+    "primary_keys",
+    "group_by_columns",
+    "num_random_rows",
+    "pct_threshold",
 ]
