@@ -17,7 +17,9 @@
 from google.cloud import bigquery
 
 from data_validation import client_info
-from data_validation.result_handlers.text import TextResultHandler
+import logging
+from data_validation import consts
+from data_validation.result_handlers.text import filter_validation_status
 
 
 class BigQueryResultHandler(object):
@@ -31,13 +33,19 @@ class BigQueryResultHandler(object):
             destination table for results.
     """
 
-    def __init__(self, bigquery_client, table_id="pso_data_validator.results"):
+    def __init__(
+        self, bigquery_client, status_list=None, table_id="pso_data_validator.results"
+    ):
         self._bigquery_client = bigquery_client
         self._table_id = table_id
+        self._status_list = status_list
 
     @staticmethod
     def get_handler_for_project(
-        project_id, table_id="pso_data_validator.results", credentials=None
+        project_id,
+        status_list=None,
+        table_id="pso_data_validator.results",
+        credentials=None,
     ):
         """Return BigQueryResultHandler instance for given project.
 
@@ -47,17 +55,25 @@ class BigQueryResultHandler(object):
             credentials (google.auth.credentials.Credentials):
                 Explicit credentials to use in case default credentials
                 aren't working properly.
+            status_list (list): provided status to filter the results with
         """
         info = client_info.get_http_client_info()
         client = bigquery.Client(
             project=project_id, client_info=info, credentials=credentials
         )
-        return BigQueryResultHandler(client, table_id=table_id)
+        return BigQueryResultHandler(client, status_list=status_list, table_id=table_id)
 
-    def execute(self, config, result_df):
-        text_handler = TextResultHandler("table")
-        text_handler.print_formatted_(result_df)
+    def execute(self, result_df):
 
+        if self._status_list is not None:
+            result_df = filter_validation_status(self._status_list, result_df)
+
+        # handler also outputs the results to the console before saving to BQ
+        logging.info(
+            result_df.drop(consts.COLUMN_FILTER_LIST, axis=1).to_markdown(
+                tablefmt="fancy_grid", index=False
+            )
+        )
         table = self._bigquery_client.get_table(self._table_id)
         chunk_errors = self._bigquery_client.insert_rows_from_dataframe(
             table, result_df
@@ -69,7 +85,7 @@ class BigQueryResultHandler(object):
             ):
                 raise RuntimeError(
                     f"Please update your BigQuery results table schema using the script : samples/bq_utils/rename_column_schema.sh.\n"
-                    f"The lastest release of DVT has updated the column name 'status' to 'validation_status': {chunk_errors}"
+                    f"The latest release of DVT has updated the column name 'status' to 'validation_status': {chunk_errors}"
                 )
             elif (
                 chunk_errors[0][0]["errors"][0]["message"]
@@ -77,7 +93,7 @@ class BigQueryResultHandler(object):
             ):
                 raise RuntimeError(
                     f"Please update your BigQuery results table schema using the script : samples/bq_utils/add_columns_schema.sh.\n"
-                    f"The lastest release of DVT has added two fields 'primary_keys' and 'num_random_rows': {chunk_errors}"
+                    f"The latest release of DVT has added two fields 'primary_keys' and 'num_random_rows': {chunk_errors}"
                 )
             raise RuntimeError(f"could not write rows: {chunk_errors}")
 
