@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import logging
 from copy import deepcopy
 
 from data_validation import consts, metadata
@@ -19,6 +19,7 @@ from data_validation.query_builder.custom_query_builder import CustomQueryBuilde
 from data_validation.query_builder.query_builder import (
     AggregateField,
     CalculatedField,
+    ComparisonField,
     FilterField,
     GroupedField,
     QueryBuilder,
@@ -227,7 +228,7 @@ class ValidationBuilder(object):
         self.group_aliases[alias] = grouped_field
 
     def add_primary_key(self, primary_key):
-        """Add ComparionField to Queries
+        """Add ComparisonField to Queries
 
         Args:
             primary_key (Dict): An object with source, target, and cast info
@@ -235,10 +236,17 @@ class ValidationBuilder(object):
         source_field_name = primary_key[consts.CONFIG_SOURCE_COLUMN]
         target_field_name = primary_key[consts.CONFIG_TARGET_COLUMN]
         # grab calc field metadata
-        alias = primary_key[consts.CONFIG_FIELD_ALIAS]
+        alias = primary_key.get(consts.CONFIG_FIELD_ALIAS)
+        cast = primary_key.get(consts.CONFIG_CAST)
         # check if valid calc field and return correct object
-        self.source_builder.add_comparison_field(source_field_name)
-        self.target_builder.add_comparison_field(target_field_name)
+        source_field = ComparisonField(
+            field_name=source_field_name, alias=alias, cast=cast
+        )
+        target_field = ComparisonField(
+            field_name=target_field_name, alias=alias, cast=cast
+        )
+        self.source_builder.add_comparison_field(source_field)
+        self.target_builder.add_comparison_field(target_field)
         self.primary_keys[alias] = primary_key
 
     def add_filter(self, filter_field):
@@ -287,9 +295,16 @@ class ValidationBuilder(object):
         target_field_name = comparison_field[consts.CONFIG_TARGET_COLUMN]
         # grab calc field metadata
         alias = comparison_field[consts.CONFIG_FIELD_ALIAS]
+        cast = comparison_field.get(consts.CONFIG_CAST)
+        source_field = ComparisonField(
+            field_name=source_field_name, alias=alias, cast=cast
+        )
+        target_field = ComparisonField(
+            field_name=target_field_name, alias=alias, cast=cast
+        )
         # check if valid calc field and return correct object
-        self.source_builder.add_comparison_field(source_field_name)
-        self.target_builder.add_comparison_field(target_field_name)
+        self.source_builder.add_comparison_field(source_field)
+        self.target_builder.add_comparison_field(target_field)
         self._metadata[alias] = metadata.ValidationMetadata(
             aggregation_type=None,
             validation_type=self.validation_type,
@@ -368,11 +383,11 @@ class ValidationBuilder(object):
                     f"Input custom query type: {self.config_manager.custom_query_type}"
                 )
         else:
-            query = self.source_builder.compile(**source_config)
+            query = self.source_builder.compile(self.validation_type, **source_config)
         if self.verbose:
-            print(source_config)
-            print("-- ** Source Query ** --")
-            print(query.compile())
+            logging.info(source_config)
+            logging.info("-- ** Source Query ** --")
+            logging.info(query.compile())
 
         return query
 
@@ -412,11 +427,11 @@ class ValidationBuilder(object):
                     f"Input custom query type: {self.config_manager.custom_query_type}"
                 )
         else:
-            query = self.target_builder.compile(**target_config)
+            query = self.target_builder.compile(self.validation_type, **target_config)
         if self.verbose:
-            print(target_config)
-            print("-- ** Target Query ** --")
-            print(query.compile())
+            logging.info(target_config)
+            logging.info("-- ** Target Query ** --")
+            logging.info(query.compile())
 
         return query
 
@@ -435,8 +450,9 @@ class ValidationBuilder(object):
         try:
             file = open(filename, "r")
             query = file.read()
+            query = query.rstrip(";\n")
         except IOError:
-            print("Cannot read query file: ", filename)
+            logging.warning("Cannot read query file: ", filename)
 
         if not query or query.isspace():
             raise ValueError(
